function love.load()
	colors = {}
	colors.white = {255,255,255,255}
	colors.purple = {128,0,128,255}
	colors.blue = {0,0,255,255}
	colors.black = {0,0,0,255}
	colors.red = {255,0,0,255}
	colors.yellow = {255,255,0,255}
	colors.orange = {255,128,0,255}
	colors.grey = {192,192,192,255}
	colors.green = {0,255,0,255}
	colors.pink = {255,0,255,255} -- used as alpha
	colors.darkred = {156,8,0,255}
	colors.brown = {80,48,17,255}
	colors.lightbrown = {168,119,61}
	
	scale = 1 -- this increases or drecreases the size of the tiles onscreen which also decreases or increases the map size
	size = 32 -- this increases or decreases the grid for stretching and skewing the tiles
	rotate = 0 -- rotate the tiles
	grid = {}
	retain = {}
	rawfiles = love.filesystem.getDirectoryItems("/")
	files = {}
	maps = {}
	for i = 1, #rawfiles do
		if string.sub(rawfiles[i], -4, -1) == ".png" then
			table.insert(files, rawfiles[i])
			--if i == 2 then
				--rawfiles[i] = changeTilePixelColors(true, rawfiles[i], "red", 0,0,0,0)
			--end
			table.insert(maps, love.image.newImageData(rawfiles[i]))

		end
	end
	
	-- a 800 x 800 map can load a 25 x 25 pixel map layout using 32 x 32 tiles
	
	windowwidth = 800
	windowheight = 800
	
	currentmap = 1 -- 

	one = love.graphics.newImage("graphics/1.png") -- 1 grass        white
	two = love.graphics.newImage("graphics/2.png") --2 cobble stone  purple
	three = love.graphics.newImage("graphics/3.png") -- 3 ice        blue
	four = love.graphics.newImage("graphics/4.png") --4 lava         black
	five = love.graphics.newImage("graphics/5.png") --5 wood floor   red
	six = love.graphics.newImage("graphics/6.png") -- 6 black marble    yellow
	seven = love.graphics.newImage("graphics/7.png") -- 7 white marble orange
	eight = love.graphics.newImage("graphics/8.png") -- 8 water      gray
	nine = love.graphics.newImage("graphics/9.png") -- 9 stone tile  green
	-- the altering of pixels should be done here rather then in draw where it can freeze the program
	--four = changeTilePixelColors(false, "graphics/4.png", "darkred", colors["purple"])

	tiles = {one, two, three, four, five, six, seven, eight, nine}
	-- for i = 1, 2 do
		 --loadmap(1)
	-- end
	loadmap(currentmap)
	
end


function love.update(dt)
end

function changeTilePixelColors(data, filename, color, ...)
	local tile_d = {} -- this will hold the image data
	local i_grid = {} -- temporary grid used to index the pixels in the image data
	tile_d = love.image.newImageData(filename) -- takes a file and stores the image data in tile_d
	for y = 1, tile_d:getHeight() do -- get the width of the image data in pixels
		i_grid[y] = {}
		for x = 1, tile_d:getWidth() do
			local r, g, b, a = tile_d:getPixel(x-1, y-1)
			if mapColor(color, r,g,b,a) then
				tile_d:setPixel(x-1, y-1, ...) -- pixel rgb and alpha to change 
			end
		end
	end
	if data then
		tile_d:encode(filename) -- make the changes and save the data as a file to be used later
		return filename
	else
		return love.graphics.newImage(tile_d) -- or just return the data as an image
	end
end

function getLevel()
	
end

function getAlpha()
end


function love.draw()
drawGrid()
end


function mapColor(name, r,g,b,a)
	local rgb = {r,g,b,a}
	local i = 1
	if r == colors[name][i] then
		if g == colors[name][i+1] then
			if b == colors[name][i+2] then
				if a == colors[name][i+3] then
					return true
				end
			end
		end
	end
	return false
end

function getCollision(obj1, obj2)
	if obj1 == obj2 then
		return false
	end
	return true
end


function loadmap(stack)
	local nmap = maps[stack] or false
	print(#maps)
	if nmap then
		grid = {}
		for z = 1, 1 do -- z coordinate
		grid[z] = {}
		for y = 1, nmap:getWidth() do -- y coordinate
			grid[z][y] = {}
			for x = 1, nmap:getHeight() do -- x coordinate
				grid[z][y][x] = {}
				local r, g, b, a = nmap:getPixel(x-1, y-1) -- 
				if mapColor("white", r,g,b,a) then
					grid[z][y][x] = 1
				elseif mapColor("purple", r,g,b,a) then
					grid[z][y][x] = 2
				elseif mapColor("blue", r,g,b,a) then
					grid[z][y][x] = 3
				elseif mapColor("black", r,g,b,a) then
					grid[z][y][x] = 4
				elseif mapColor("red", r,g,b,a) then
					grid[z][y][x] = 5
				elseif mapColor("yellow", r,g,b,a) then
					grid[z][y][x] = 6
				elseif mapColor("orange", r,g,b,a) then
					grid[z][y][x] = 7
				elseif mapColor("grey", r,g,b,a) then
					grid[z][y][x] = 8
				elseif mapColor("green", r,g,b,a) then
					grid[z][y][x] = 9
				end
			end
		end
		end
		--currentmap = stack
	end
end


function drawGrid()
	for z = 1, #grid do
		for y = 1, #grid[z] do
			for x = 1, #grid[z][y] do
				local posx = (x - 1) * size -- lay each tile starting at 0 in the x, stetch it at tile size
				local posy = (y - 1) * size -- lay each tile starting at 0 in the y, stetch it at tile size
				local posz = z -- lay each tile starting at 0 in the y, stetch it at tile size
				if grid[z][y][x] == 1 then
					love.graphics.draw(one, posx * scale, posy * scale, rotate, scale, scale)
					
				elseif grid[z][y][x] == 2 then
					love.graphics.draw(two, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 3 then	
					love.graphics.draw(three, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 4 then
					love.graphics.draw(four, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 5 then
					
					love.graphics.draw(five, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 6 then
					love.graphics.draw(six, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 7 then
					love.graphics.draw(seven, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 8 then
					love.graphics.draw(eight, posx * scale, posy * scale, rotate, scale, scale)
				elseif grid[z][y][x] == 9 then
					love.graphics.draw(nine, posx * scale, posy * scale, rotate, scale, scale)
				end
			end
		end
		
	end
end

